// Copyright (C) 1998 Logi Ragnarsson

package is.logi.crypto.keys;
import is.logi.crypto.*;
import is.logi.crypto.hash.*;
import is.logi.crypto.sign.*;

/**
 * This interface is implemented by keys that can be used to
 * create and validate signatures on blocks of data.
 * 
 * @author <a href="http://www.hi.is/~logir/">Logi Ragnarsson</a>
 * (<a href="mailto:logir@hi.is">logir@hi.is</a>) */
public interface SignatureKey extends Key {

  /**
   * Returns the maximum size in bytes of the fingerprints
   * that can be signed. */
  public int signBlockSize();

  /**
   * Returns the length of a signature in bytes. */
  public int signatureSize();

  /**
   * Create a signature for a Fingerprint.
   *
   * @exception KeyException if this key can't be used to sign
   *            this fingerprint for some reason. */
  public Signature sign(Fingerprint fp) throws KeyException ;
  
  /**
   * Verify a Signature on a Fingerprint.
   * <p>
   * The methor returns true iff <code>s</code> is a signature for
   * <code>fp</code> created with this key in the case of a symmetric
   * key, or the other key in the pair in the case of an asymmetric key.
   */
  public boolean verify(Signature s, Fingerprint fp);
  
}
